# dbgprint

Debug Print is a handy command line print app used for debugging loops and variable changes over time.

It has features for tracking pivots in a while and for loop, and also print the information and data types of variables

Its dependencies are termcolor and colorama.

For python package: https://pypi.org/project/dbgprint/

For github repo: https://github.com/youhengzhou/dbgprint

# Download Package

`py -m pip install dbgprint -U`

## In Your Python Files

`import dbgprint`

# Commands

## Create command:

`dbgprint.data(dataContent, dataName, action)`
This will print the data's contents, the data's variable name, and the actions associated with the data at your discretion.
